==> javie-0.3.0-src.tar.gz: javie-0.3.0-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/templates/EffectTemplate.java <==
/*
 * Copyright (c) 2009 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal.templates;

import net.arnx.jsonic.JSONHint;
import ch.kuramo.javie.api.VideoBounds;
import ch.kuramo.javie.api.plugin.PIAudioBuffer;
import ch.kuramo.javie.api.plugin.PIVideoBuffer;
import ch.kuramo.javie.core.AbstractEffect;
import ch.kuramo.javie.core.services.EffectRegistry;

import com.google.inject.Inject;
import com.google.inject.Injector;

class EffectTemplate extends AbstractEffect {

	@Inject
	public EffectTemplate(Injector injector, EffectRegistry registry) {
		super(injector, registry);
	}

	protected Class<?> getInteriorClass() {
		// javassistで書き換える。
		throw new Error();
	}

	@JSONHint(name="TYPE")
	public String getType() {
		// javassistで書き換える。
		throw new Error();
	}

	@JSONHint(ignore=true)
	public VideoBounds getVideoBounds() {
		// javassistで書き換える。
		return null;
	}

	public PIVideoBuffer doVideoEffect() {
		// javassistで書き換える。
		return null;
	}

	public PIAudioBuffer doAudioEffect() {
		// javassistで書き換える。
		return null;
	}

}

==> javie-0.3.4-src.tar.gz: javie-0.3.4-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/templates/EffectTemplate.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal.templates;

import net.arnx.jsonic.JSONHint;
import ch.kuramo.javie.api.IAudioBuffer;
import ch.kuramo.javie.api.IVideoBuffer;
import ch.kuramo.javie.api.VideoBounds;
import ch.kuramo.javie.core.AbstractEffect;
import ch.kuramo.javie.core.services.EffectRegistry;

import com.google.inject.Inject;
import com.google.inject.Injector;

class EffectTemplate extends AbstractEffect {

	@Inject
	public EffectTemplate(Injector injector, EffectRegistry registry) {
		super(injector, registry);
	}

	protected Class<?> getInteriorClass() {
		// javassistで書き換える。
		throw new Error();
	}

	@JSONHint(name="TYPE")
	public String getType() {
		// javassistで書き換える。
		throw new Error();
	}

	@JSONHint(ignore=true)
	public VideoBounds getVideoBounds() {
		// javassistで書き換える。
		return null;
	}

	public IVideoBuffer doVideoEffect() {
		// javassistで書き換える。
		return null;
	}

	public IAudioBuffer doAudioEffect() {
		// javassistで書き換える。
		return null;
	}

}
